YAML — Translate Toolkit 2.5.0 documentation

# YAML

New in version 2.0.0.

YAML is a common format for web data interchange. The two variants of YAML files are supported:

- Plain YAML files.
- Ruby YAML localization files with root node as language. This variant supports plurals as well.

# Non-Conformance

The following are not yet supported (in most cases these are properly parsed, but not saved in round trip):

- Abbreviated lists:

      first-name: [Sun, Mon, Tue, Wed, Thu, Fri, Sat]

- Abbreviated dictionaries:

      martin: {name: Martin D'vloper, job: Developer, skill: Elite}

- Booleans:

      foo: True